@@ -8,7 +8,7 @@ from .Query import Query, Wait, QueryType
 
 
 def send_query_to_listener(query):
-    from DjangoLoadBalancer.DjangoLoadBalancer.local_settings import LOAD_BALANCER
+    from .local_settings import LOAD_BALANCER
     address = (LOAD_BALANCER['ADDRESS']['HOST'], LOAD_BALANCER['ADDRESS']['PORT'])
     connection = Client(address, authkey=bytes(LOAD_BALANCER['ADDRESS']['AUTHKEY'], 'utf-8'))
     payload = pickle.dumps(query)
@@ -21,7 +21,7 @@ def send_query_to_listener(query):
 
 def loadbalance_function(name):
     def loadbalanced_function(self, *args, **kwargs):
-        query = Query(Wait.WAIT, QueryType.QUERYSET, method=name, args=args, kwargs=kwargs, model=self.model)
+        query = Query(Wait.WAIT.value, QueryType.QUERYSET.value, method=name, args=args, kwargs=kwargs, model=self.model)
         result = send_query_to_listener(query)
         return result
 
@@ -50,7 +50,7 @@ class LoadBalancerManager(BaseLoadBalancerManager):
         super(LoadBalancerManager, self).__init__()
 
     def get_queryset(self):
-        query = Query(Wait.DONT_WAIT, QueryType.NO_QUERYSET, method='get_queryset', model=self.model)
+        query = Query(Wait.DONT_WAIT.value, QueryType.NO_QUERYSET.value, method='get_queryset', model=self.model)
         result = send_query_to_listener(query)
         return result
 
@@ -61,12 +61,12 @@ class LoadBalancerModel(models.Model):
     objects = LoadBalancerManager()
 
     def save(self, *args, **kwargs):
-        query = Query(wait=Wait.WAIT, type=QueryType.NO_QUERYSET, method='save', model=self, args=args, kwargs=kwargs)
+        query = Query(wait=Wait.WAIT.value, type=QueryType.NO_QUERYSET.value, method='save', model=self, args=args, kwargs=kwargs)
         result = send_query_to_listener(query)
         return result
 
     def delete(self, *args, **kwargs):
-        query = Query(wait=Wait.WAIT, type=QueryType.NO_QUERYSET, method='delete', model=self, args=args, kwargs=kwargs)
+        query = Query(wait=Wait.WAIT.vale, type=QueryType.NO_QUERYSET.value, method='delete', model=self, args=args, kwargs=kwargs)
         result = send_query_to_listener(query)
         return result
 
